@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Access to the AcousticBrainz API
 
-our $VERSION = '0.0500';
+our $VERSION = '0.0600';
 
 use Moo;
 use strictures 2;
@@ -11,7 +11,6 @@ use namespace::clean;
 
 use Carp;
 use Mojo::UserAgent;
-use Mojo::JSON::MaybeXS;
 use Mojo::JSON qw( decode_json );
 use Mojo::URL;
 use Try::Tiny;
@@ -19,7 +18,7 @@ use Try::Tiny;
 
 has base => (
     is      => 'rw',
-    default => sub { 'https://acousticbrainz.org/api/v1' },
+    default => sub { 'https://acousticbrainz.org' },
 );
 
 
@@ -37,7 +36,7 @@ sub fetch {
     croak 'No query provided' unless $args{query};
 
     my $url = Mojo::URL->new($self->base)
-        ->path($args{mbid} . '/'. $args{endpoint})
+        ->path('/api/v1/' . $args{mbid} . '/'. $args{endpoint})
         ->query(%{ $args{query} });
 
     my $tx = $self->ua->get($url);
@@ -84,7 +83,7 @@ WebService::AcousticBrainz - Access to the AcousticBrainz API
 
 =head1 VERSION
 
-version 0.0500
+version 0.0600
 
 =head1 SYNOPSIS
 
@@ -106,7 +105,7 @@ C<WebService::AcousticBrainz> provides access to the L<https://acousticbrainz.or
 
 =head2 base
 
-The base URL.  Default: https://acousticbrainz.org/api/v1
+The base URL.  Default: https://acousticbrainz.org
 
 =head2 ua
 
@@ -114,13 +113,13 @@ The user agent.
 
 =head1 METHODS
 
-=head2 new()
+=head2 new
 
   $w = WebService::AcousticBrainz->new;
 
 Create a new C<WebService::AcousticBrainz> object.
 
-=head2 fetch()
+=head2 fetch
 
   $r = $w->fetch(%arguments);
 
@@ -129,15 +128,19 @@ optional B<query> arguments.
 
 =head1 SEE ALSO
 
+The F<t/*> tests
+
+The F<eg/*> programs
+
+L<https://acousticbrainz.org/data>
+
 L<Moo>
 
 L<Mojo::UserAgent>
 
 L<Mojo::JSON>
 
-L<Mojo::JSON::MaybeXS>
-
-L<https://acousticbrainz.org/data>
+L<Try::Tiny>
 
 =head1 AUTHOR
 
